From 6afd14cf08001b0a871c7254f7e012c780622f45 Mon Sep 17 00:00:00 2001
From: Steven Toth <stoth@kernellabs.com>
Date: Tue, 11 Jul 2017 18:27:29 -0400
Subject: [PATCH] SCTE35 / CUEI Descriptor parsing bug. Descriptor lengths of
 one byte fail to parse, instead returning null.

The Spec from 2004 to 2016 shows the descriptor payload has never been
more than a single byte.
See SCTE 35 2016 Page 19 Table 2 (Section 8.2).

Correct the length validation check, and reject any descriptor that
IS NOT one byte long, as per the spec.
---
 src/descriptors/custom/dr_8a_scte.c | 2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

diff --git a/src/descriptors/custom/dr_8a_scte.c b/src/descriptors/custom/dr_8a_scte.c
index 4ce847e..0639b8c 100644
--- a/src/descriptors/custom/dr_8a_scte.c
+++ b/src/descriptors/custom/dr_8a_scte.c
@@ -53,7 +53,7 @@ dvbpsi_scte_cuei_dr_t * dvbpsi_decode_scte_cuei_dr(dvbpsi_descriptor_t * p_descr
     if (dvbpsi_IsDescriptorDecoded(p_descriptor))
         return p_descriptor->p_decoded;
 
-    if (p_descriptor->i_length == 0x01)
+    if (p_descriptor->i_length != 0x01)
         return NULL;
 
     /* Allocate memory */
-- 
2.8.4 (Apple Git-73)

